<?php

/**
* Set your language here
*/

/*
Uncomment the line above the function to make the wolf_set_lang function active
Replace the languague code by your own
The .po and .mo files can be found in the languages/ folder
*/

if ( ! function_exists( 'wolf_set_lang' ) ) :
// add_filter( 'locale', 'wolf_set_lang' );
function wolf_set_lang( $locale ) {
	return 'fr_FR';
}
endif;


/**
 * Main Wordpress content width
 */
if ( ! isset( $content_width ) )
	$content_width = 1200;


/*-----------------------------------------------------------------------------------*/
/*	Enqueue Front end Styles
/*-----------------------------------------------------------------------------------*/

/**
 * Enqueue CSS stylsheets
 * JS scripts are separated and can be found in includes/scripts.php
 */
function wolf_enqueue_style() {
	global $wp_styles;

	if ( get_theme_mod( 'lightbox' ) == 'swipebox' ) {

		wp_enqueue_style( 'swipebox', WOLF_THEME_URL. '/css/lib/swipebox.min.css', array(), '1.2.8' );

	} elseif ( get_theme_mod( 'lightbox' ) == 'fancybox' ) {

		wp_enqueue_style( 'fancybox', WOLF_THEME_URL. '/css/lib/fancybox.css', array(), '2.1.4' );

	}

	/* Ensure to overwrite flexslider style enqueued by a plugin */
	wp_dequeue_style( 'flexslider' );
	wp_deregister_style( 'flexslider' );

	wp_enqueue_style( 'flexslider', WOLF_THEME_URL. '/css/lib/flexslider.css', array(), '2.2.0' );

	/* Main Stylesheet */
	wp_enqueue_style( 'flycase-style', get_stylesheet_uri(), array(), WOLF_THEME_VERSION );

	/* Loads the Internet Explorer specific stylesheet. */
	wp_enqueue_style( 'flycase-ie8-style', WOLF_THEME_URL . '/css/ie8.css' );
	$wp_styles->add_data( 'flycase-ie8-style', 'conditional', 'lte IE 8' );


}
add_action( 'wp_print_styles', 'wolf_enqueue_style' );

// --------------------------------------------------------------------------

/**
 *  Allow Shortcodes in Text Widget
 */
add_filter( 'widget_text', 'shortcode_unautop' );
add_filter( 'widget_text', 'do_shortcode' );

// --------------------------------------------------------------------------

if ( ! function_exists( 'wolf_body_classes' ) ) :
/**
 * Add specific class to the body depending on theme options
 */
function wolf_body_classes( $classes ) {

	global $wp_customize;

	if ( isset( $wp_customize ) ) {
		$classes[] = 'is-customizer';
	}

	$classes[] = 'wolf';

	/* Page template clean classes */
	if ( is_page_template( 'page-templates/full-width.php' ) )
		$classes[] = 'full-width';

	if ( is_page_template( 'page-templates/masonry.php' ) )
		$classes[] = 'masonry-template';

	if ( is_page_template( 'videos-template.php' ) )
		$classes[] = 'video-gallery-template';

	if ( is_page_template( 'albums-template.php' ) )
		$classes[] = 'albums-template';

	/* Responsive layout class */
	if ( wolf_get_theme_option( 'responsive' ) )
		$classes[] = 'is-responsive';

	/* Add a class if the user choose the sticky menu option  */
	if ( get_theme_mod( 'sticky_menu' ) )
		$classes[] = 'sticky-menu';

	/* Add a class if the user choose the center menu option  */
	if ( get_theme_mod( 'center_menu' ) )
		$classes[] = 'center-menu';

	/* Add a class if the user choose to disable the mobile menu  */
	if ( get_theme_mod( 'no_mobile_menu' ) )
		$classes[] = 'no-mobile-menu';

	/* Add a class if the user choose to use rev slider cusom style  */
	if ( wolf_get_theme_option( 'wolf_rev_custom' ) )
		$classes[] = 'wolf-rev-custom';

	/* Add a class if the user choose to use woocommerce cusom style  */
	if ( wolf_get_theme_option( 'wolf_woocommerce' ) )
		$classes[] = 'wolf-woocommerce';

	/* Add a class if the user choose to use theme button style for woocomerce  */
	if ( wolf_get_theme_option( 'wolf_woocommerce_buttons' ) )
		$classes[] = 'wolf-woocommerce-buttons';

	if ( wolf_get_theme_option( 'wolf_woocommerce_fullwidth' ) )
		$classes[] = 'wolf-woocommerce-fullwidth';

	if (
		wolf_get_theme_option( 'discography_grid' )
		&& ! is_singular( 'release' )
		&& ( 'release' == get_post_type() || ( function_exists( 'wolf_discography_get_page_id' ) && is_page( wolf_discography_get_page_id() ) ) )
	)
		$classes[] = 'discography-grid';

	/* Add a class if the user choose to use woocommerce cusom style  */
	if ( wolf_get_theme_option( 'wolf_mailchimp' ) )
		$classes[] = 'wolf-mailchimp';

	/* Home Header Type */
	if ( wolf_get_theme_option( 'home_header_type' ) )
		$classes[] = 'home-header-' . wolf_get_theme_option( 'home_header_type' );

	/* No loader option class */
	if ( wolf_get_theme_option( 'no_loader' ) )
		$classes[] = 'no-loader';

	if ( is_multi_author() )
		$classes[] = 'is-multi-author';

	/* Layout Class (wrapped or full width container) */
	$classes[] = get_theme_mod( 'page_container', 'fullwidth' );

	return $classes;
}
add_filter( 'body_class', 'wolf_body_classes' );
endif;

// --------------------------------------------------------------------------

if ( ! function_exists( 'wolf_is_revslider_in_home_header_body_class' ) ) :
/**
 * Add body class if there is a rev slider in home header
 * Not used
 */
function wolf_is_revslider_in_home_header_body_class( $classes ) {

	$home_header_content = wolf_get_theme_option( 'home_header_content_bg' );
	$pattern = get_shortcode_regex();

	if ( $home_header_content && preg_match( "/$pattern/s", $home_header_content, $match ) ) {

		if ( 'rev_slider' == $match[2] ) {
			$classes[] = 'home-header-has-revslider';
		}
	}

	return $classes;

}
add_filter( 'body_class', 'wolf_is_revslider_in_home_header_body_class' );
endif;

// --------------------------------------------------------------------------

if ( ! function_exists( 'wolf_get_custom_index_page_id' ) ) :
/**
 * Returns page ID of specific post types index page if exists
 */
function wolf_get_custom_index_page_id( $name = '' ){

	$pages = get_pages( array(
		'meta_key' => '_wp_page_template',
		'meta_value' => $name . '-template.php'
	) );
	if ( $name && $pages && isset( $pages[0] ) )
		return $pages[0]->ID;
}
endif;

/*---------------------------------------------------------------------------------------------------------
* From here, all functions can be overwritten in a child theme functions.php file
*---------------------------------------------------------------------------------------------------------*/

if ( ! function_exists( 'wolf_page_loader' ) ) :
function wolf_page_loader() {

	if ( ! wolf_get_theme_option( 'no_loader' ) ) :
	?>
	<div id="overlay"><div id="loader"></div></div>
	<?php
	endif;
}
add_action( 'wolf_header_before', 'wolf_page_loader' );
endif;

// --------------------------------------------------------------------------

if ( ! function_exists( 'wolf_logo' ) ) :
/**
 * Display the Logo
 */
function wolf_logo() {

	$logo = get_theme_mod( 'logo');

	if ( $logo ) {

		$output = '<div id="logo-container"><div class="wrap" id="logo">
		<a href="' . esc_url( home_url( '/' ) ) . '" rel="home">
			<img src="' . $logo . '" alt="' . esc_attr( get_bloginfo( 'name') ) . '">
		</a>
		</div></div>';
		echo $output;
	}
}
endif;



// --------------------------------------------------------------------------

if( ! function_exists( 'wolf_top_arrow' ) ) :
/**
 * Output "Back to the top" arrow
 */
function wolf_top_arrow() {
	echo '<div id="top"></div><a id="top-arrow" class="scroll" href="#top"></a>';
}
add_action( 'wolf_body_start', 'wolf_top_arrow' );
endif;

// --------------------------------------------------------------------------

/**
 * Display the top bar
 */
if( ! function_exists( 'wolf_top_bar' ) ) :
function wolf_top_bar() {
	?>
	<div id="top-bar">
		<div class="wrap">
			<div class="right">
				<nav id="site-navigation-secondary" class="navigation secondary-navigation" role="navigation">
					<?php wp_nav_menu( array( 'theme_location' => 'secondary', 'menu_class' => 'nav-menu-secondary', 'fallback_cb'  => '' ) ); ?>
				</nav><!-- #site-navigation -->
			</div>
			<div class="socials left">
				<?php wolf_theme_socials(); ?>
			</div><!-- .socials -->
		</div>
	</div>
	<?php
}
add_action( 'wolf_header_before', 'wolf_top_bar' );
endif;

// --------------------------------------------------------------------------

if ( ! function_exists( 'wolf_theme_socials' ) ) :
/**
 * Displays social icons
 */
function wolf_theme_socials() {
	$socials = array(
		'facebook',
		'twitter',
		'linkedin',
		'digg',
		'instagram',
		'dribbble',
		'youtube',
		'google-plus',
		'pinterest',
		'vimeo',
		'deviantart',
		'github',
		'tumblr',
		'skype' ,
		'lastfm' ,
		'soundcloud',
		'spotify',
		'delicious' ,
		'stumbleupon' ,
		'forrst',
		'foursquare',
		'zerply',
		'myspace',
		'grooveshark',
		'evernote',
		'behance',
		'pixels',
		'rss'
	);
	foreach( $socials as $s ) :
		if( wolf_get_theme_option( $s ) ) :
		?>
		<a href="<?php echo wolf_get_theme_option($s); ?>" class="icon-<?php echo $s; ?>" title="<?php echo ucfirst( $s ) ?>" target="_blank"></a>
		<?php endif; ?>
	<?php
	endforeach;
}
endif;


// --------------------------------------------------------------------------

if ( ! function_exists( 'wolf_hello' ) ) :
/**
 * Output home page header content in every pages
 */
function wolf_hello() {

	$hello = wolf_get_theme_option( 'home_header_content' );

	if (
		is_front_page() &&
		$hello
	) :
	?>
	<?php get_template_part( 'partials/home', 'header' ); ?>
	<?php
	endif;
}
add_action( 'wolf_header_start', 'wolf_hello' );
endif;

// --------------------------------------------------------------------------

if( ! function_exists( 'wolf_top_arrow' ) ) :
/**
 * Output "Back to the top" arrow
 */
function wolf_top_arrow()
{
	echo '<div id="top"></div><a id="top-arrow" class="scroll" href="#top"></a>';
}
add_action( 'wolf_body_start', 'wolf_top_arrow' );
endif;

// --------------------------------------------------------------------------

if( ! function_exists( 'wolf_share_links' ) ) :
/**
 * Share links below single blog posts
 */
function wolf_share_links( $display = true ) {
	$text = wolf_get_theme_option( 'share_text' );
	$link = urlencode( get_permalink() );
	$title = urlencode( get_the_title() );
	$pin_img = wolf_get_post_thumbnail_url( 'full' );
	if ( $display ) : // is theme option checked
	?>
	<div class="share-box">
		<div class="share-box-inner clearfix">
			<div class="share-box-title">
				<h4 class="share-title"><?php echo $text; ?></h4>
			</div>
			<div class="share-box-icons">
				<?php if( wolf_get_theme_option( 'share_facebook' ) ) : ?>
				<a data-popup="true" data-width="580" data-height="320" href="http://www.facebook.com/sharer.php?u=<?php echo $link; ?>&amp;t=<?php echo $title; ?>" class="icon-facebook share-link" title="<?php printf( __( 'Share on %s', 'wolf' ), ucfirst( 'facebook' ) ); ?>"></a>
				<?php endif; ?>
				<?php if( wolf_get_theme_option( 'share_twitter' ) ) : ?>
				<a data-popup="true" href="http://twitter.com/home?status=<?php echo $title . ' - ' . $link; ?>" class="icon-twitter share-link" title="<?php printf( __( 'Share on %s', 'wolf' ), ucfirst( 'twitter' ) ); ?>"></a>
				<?php endif; ?>
				<?php if( wolf_get_theme_option( 'share_pinterest' ) ) : ?>
				<a data-popup="true" data-width="580" data-height="300" href="http://pinterest.com/pin/create/button/?url=<?php echo $link; ?>&amp;media=<?php echo $pin_img; ?>&amp;description=<?php echo $title; ?>" class="icon-pinterest share-link" title="<?php printf( __( 'Share on %s', 'wolf' ), ucfirst( 'pinterest' ) ); ?>"></a>
				<?php endif; ?>
				<?php if( wolf_get_theme_option( 'share_google_plus' ) ) : ?>
				<a data-popup="true" data-height="500" href="https://plus.google.com/share?url=<?php echo $link; ?>" class="icon-google-plus share-link" title="<?php printf( __( 'Share on %s', 'wolf' ), ucfirst( 'google plus' ) ); ?>"></a>
				<?php endif; ?>
				<?php if( wolf_get_theme_option( 'share_tumblr' ) ) : ?>
				<a data-popup="true" href="http://tumblr.com/share/link?url=<?php echo $link; ?>&amp;name=<?php echo $title; ?>" class="icon-tumblr share-link" title="<?php printf( __( 'Share on %s', 'wolf' ), ucfirst( 'tumblr' ) ); ?>"></a>
				<?php endif; ?>
				<?php if( wolf_get_theme_option( 'share_stumbleupon' ) ) : ?>
				<a data-popup="true" data-width="800" data-height="600" href="http://www.stumbleupon.com/submit?url=<?php echo $link; ?>&amp;title=<?php echo $title; ?>" class="icon-stumbleupon share-link" title="<?php printf( __( 'Share on %s', 'wolf' ), ucfirst( 'stumbleupon' ) ); ?>"></a>
				<?php endif; ?>
				<?php if( wolf_get_theme_option( 'share_linkedin' ) ) : ?>
				<a data-popup="true" data-height="380" href="http://www.linkedin.com/shareArticle?mini=true&amp;url=<?php echo $link; ?>&amp;title=<?php echo $title; ?>" class="icon-linkedin share-link" title="<?php printf( __( 'Share on %s', 'wolf' ), ucfirst( 'linkedin' ) ); ?>"></a>
				<?php endif; ?>
				<?php if( wolf_get_theme_option( 'share_mail' ) ) : ?>
				<a data-popup="true" href="mailto:?subject=<?php echo $title; ?>&amp;body=<?php echo $link; ?>" class="icon-mail share-link" title="<?php printf( __( 'Share by %s', 'wolf' ), ucfirst( 'email' ) ); ?>"></a>
				<?php endif; ?>
			</div>
		</div>
	</div>
	<div class="clear"></div>
	<?php
	endif;
}
//add_action( 'wolf_post_end_singular', 'wolf_share_links' );
endif;


/*-----------------------------------------------------------------------------------*/
/*	Authors
/*-----------------------------------------------------------------------------------*/

if ( ! function_exists( 'wolf_add_author_socials' ) ) :
/**
 * Add social networks to author profile
 */
function wolf_add_author_socials( $contactmethods ) {
	$contactmethods = array();
	$contactmethods['twitter'] = 'Twitter';
	$contactmethods['facebook'] = 'Facebook';
	return $contactmethods;
}
add_filter( 'user_contactmethods', 'wolf_add_author_socials',10,1 );
endif;

// --------------------------------------------------------------------------

if( ! function_exists( 'wolf_display_author_socials' ) ) :
/**
 * Display social networks in author bio box
 */
function wolf_display_author_socials() {
	$facebook = get_the_author_meta( 'facebook' );
	$twitter = get_the_author_meta( 'twitter' );
	$website = get_the_author_meta( 'user_url' );
	$name = get_the_author_meta( 'user_nicename' );
	if( $facebook )
		echo '<a target="_blank" title="' . sprintf( __( 'View %s facebook profile', 'wolf' ), $name ) . '" href="'. $facebook .'" class="author-link icon-facebook"></a>';
	if( $twitter )
		echo '<a target="_blank" title="' . sprintf( __( 'Follow %s on twitter', 'wolf' ), $name ) . '" href="'. $twitter .'" class="author-link icon-twitter"></a>';
	if( $website )
		echo '<a target="_blank" title="' . sprintf( __( 'Visit %s website', 'wolf' ), $name ) . '" href="'. $website .'" class="author-link icon-website"></a>';
}
endif;

// --------------------------------------------------------------------------

if ( ! function_exists( 'wolf_author_meta' ) ) :
/**
 * Output author bio box
 */
function wolf_author_meta() {

	if ( ( get_post_type() == 'post'  ||  get_post_type() == 'review' )
		&& is_multi_author()
		&& get_the_author_meta( 'description' )
		&& wolf_get_theme_option( 'show_author_box' ) )
	{
		get_template_part( 'author-bio' );
	}

}
// add_action( 'wolf_post_end_singular', 'wolf_author_meta' );
endif;

// --------------------------------------------------------------------------

if ( ! function_exists( 'wolf_theme_socials' ) ) :
/**
 * Returns social icons
 */
function wolf_theme_socials() {

	$output = null;

	$socials = array(
		'facebook',
		'twitter',
		'instagram',
		'youtube',
		'vimeo',
		'soundcloud',
		'spotify',
		'myspace',
		'grooveshark',
		'lastfm' ,
		'google-plus',
		'pinterest',
		'tumblr',
		'skype' ,
		'linkedin',
		'digg',
		'dribbble',
		'deviantart',
		'github',
		'delicious' ,
		'stumbleupon' ,
		'forrst',
		'foursquare',
		'zerply',
		'evernote',
		'behance',
		'pixels',
		'rss'
	);
	foreach($socials as $s) :

		$social = wolf_get_theme_option( $s );
		if ( $social ) {
			$output .= '<a href="' . $social . '" class="icon-' . $s . '" title="'. ucfirst($s) . '" target="_blank"></a>';
		}
	endforeach;

	return $output;
}
endif;

// --------------------------------------------------------------------------

if ( ! function_exists( 'wolf_output_music_network' ) ) :
/**
 * Output music network icons
 */
function wolf_output_music_network() {

	if ( function_exists( 'wolf_music_network' ) ) {
		echo '<div class="wolf-music-social-icons-container">';
		wolf_music_network( '32', 'center' );
		echo '</div>';
	}

}
add_action( 'wolf_footer_start', 'wolf_output_music_network' );
endif;


// --------------------------------------------------------------------------

if ( ! function_exists( 'wolf_no_js_message' ) ) :
/**
 * No Javascript message
 */
function wolf_no_js_message() {
	?>
<noscript>
	<div id="no-js-message">
		<div>
			<?php printf( __( '<strong>JavaScript must be <a href="%s" target="_blank">enabled</a> in order for you to view this website in full form.
				</strong>However, it seems JavaScript is either disabled or not supported by your browser.
				To view this website properly, enable JavaScript by changing your browser options,
				and then try again.', 'wolf' ), 'http://enable-javascript.com/' ); ?>
		</div>
	</div>
</noscript>
	<?php
}
add_action( 'wolf_body_end_home', 'wolf_no_js_message' );
endif;


// --------------------------------------------------------------------------

if ( ! function_exists( 'wolf_top_tags' ) ) :
/**
 * Display the most used tags
 */
function wolf_top_tags( $text = '', $nb = 10 ) {
	$tags = get_tags();

	$list = '';

	if ( empty( $tags ) )
		return;

	$counts = $tag_links = array();

	foreach ( (array) $tags as $tag ) {
		$counts[$tag->name] = $tag->count;
		$tag_links[$tag->name] = get_tag_link( $tag->term_id );
	}
	asort( $counts );
	$counts = array_reverse( $counts, true );
	$i = 0;
	foreach ( $counts as $tag => $count ) {
		$i++;
		$tag_link = esc_url( $tag_links[$tag] );

		$tag = str_replace(' ', '&nbsp;', esc_html( $tag ) );

		if ( $i < $nb ){
			$list .= "<a href=\"$tag_link\">$tag</a>, ";
		}
	}

	echo $text . substr( $list, 0, -2 );
}
endif;



// --------------------------------------------------------------------------

if ( ! function_exists( 'wolf_post_class' ) ) :
/**
 * Add custom classes to each post
 */
function wolf_post_class( $classes ) {

	$format = null;

	$is_embed_video = false;
	$content = get_the_content();
	$has_post_thumbnail = has_post_thumbnail();

	$format = get_post_format();

	$featured = get_post_meta( get_the_ID(), '_wolf_featured_post', true );

	$has_media = wolf_post_media( false );

	if( $featured )
		$classes[] = 'is-featured';

	if( $has_media )
		$classes[] = 'has-media';

	if ( $has_post_thumbnail )
			$classes[] = 'has-thumbnail';

	if ( ! $has_post_thumbnail )
		$classes[] = 'no-thumbnail';

	$pattern = get_shortcode_regex();

	if ( preg_match( "/$pattern/s", $content, $match ) ) {
		if ( 'video' == $match[2] ) {
			$classes[] = 'is-embed-video';
			$is_embed_video = true;
		}
	}

	if ( preg_match( "/$pattern/s", $content, $match ) ) {
		if ( 'audio' == $match[2] ) {
			$classes[] = 'is-embed-audio';
		}
	}

	if ( preg_match( wolf_get_regex( 'twitter' ), $content ) ) {
		$classes[] = 'has-tweet';
	}

	if ( $format ) {

		if ( wolf_get_first_soundcloud_url() && $format == 'audio' )
			$classes[] = 'is-soundcloud';

		if ( wolf_get_first_video_url() || $is_embed_video && $format == 'video' )
			$classes[] = 'is-video';

		if ( ( $format == 'aside' || $format == 'status' ) && preg_match( wolf_get_regex( 'twitter' ), $content ) ) {
			$classes[] = 'is-tweet';
		}

		if( $format == 'image' && preg_match( wolf_get_regex( 'instagram' ), $content ) )
			$classes[] = 'is-instagram';

	}

	return $classes;
}
add_filter( 'post_class', 'wolf_post_class' );
endif;

// --------------------------------------------------------------------------

if ( ! function_exists( 'wolf_excerpt_length' ) ) :
/**
 * Excerpt length hook
 * Set the number of words to display in the excerpt
 */
function wolf_excerpt_length($length) {
	return 50;
}
add_filter( 'excerpt_length', 'wolf_excerpt_length' );
endif;

// --------------------------------------------------------------------------


if ( ! function_exists( 'wolf_more_text' ) ) :
/**
 * Excerpt more
 * Render "Read more" link text differenttly depending on post format
 * the_content( wolf_more_text() )
 */
function wolf_more_text() {
	global $post;

	$format = null;
	$text = __('Read more &rarr;', 'wolf');
	$format = get_post_format();

	if ( $format ) {

		if ( $format == 'video' ) {

		 	$text = __( 'More about this video &rarr;', 'wolf' );

		}elseif ( $format == 'gallery' ||  $format == 'image' ) {

			$text = __( 'View more &rarr;', 'wolf' );

		}elseif ( $format == 'audio' ) {

			$text = __( 'More about this song &rarr;', 'wolf' );

		}else{
			$text = __( 'Read more &rarr;', 'wolf' );
		}
	}

	return $text;

}
endif;


// --------------------------------------------------------------------------

if ( ! function_exists( 'wolf_excerpt_more' ) ) :
/**
 * Excerpt more
 */
function wolf_excerpt_more( $more ) {

	return '<p><a rel="bookmark" class="more-link" href="'. get_permalink( get_the_ID() ) . '">' . wolf_more_text() . '</a></p>';

}
add_filter( 'excerpt_more', 'wolf_excerpt_more' );
endif;

// --------------------------------------------------------------------------

if( ! function_exists( 'wolf_remove_more_jump_link' ) ) :
/**
 * Avoid page jump when clicking on more link
 */
function wolf_remove_more_jump_link( $link )  {
	$offset = strpos( $link, '#more-' );
	if ( $offset ) { $end = strpos( $link, '"',$offset ); }
	if ( $end ) { $link = substr_replace( $link, '', $offset, $end-$offset ); }
	return $link;
}
add_filter( 'the_content_more_link', 'wolf_remove_more_jump_link' );
endif;


if ( ! function_exists('wolf_is_woocommerce') ) :
/**
 * Check if we are on a woocommerce page
 */
function wolf_is_woocommerce() {

	if ( class_exists( 'Woocommerce' ) ) {

		if ( is_woocommerce() ) {
			return true;
		}

		if ( is_checkout() || is_order_received_page() ) {
			return true;
		}

		if ( is_cart() ) {
			return true;
		}

		if ( is_account_page() ) {
			return true;
		}

	}

}
endif;

// --------------------------------------------------------------------------

if ( ! function_exists( 'wolf_get_woocommerce_shop_page_id' ) ) :
/**
 * Check if we are on a woocommerce page
 */
function wolf_get_woocommerce_shop_page_id() {

	$page_id = null;

	//debug( get_option( 'woocommerce_shop_page_id' ) );

	if ( class_exists( 'Woocommerce' ) ) {

		$page_id = get_option( 'woocommerce_shop_page_id' );
	}

	return $page_id;

}
endif;


// --------------------------------------------------------------------------

if ( ! function_exists( 'wolf_get_page_title' ) ) :
/**
 * Returns page title outside the loop
 */
function wolf_get_page_title() {

	global $post, $wp_query;
	$title = null;
	$desc = null;
	$output = null;


	if ( have_posts() ) :

		/* Main condition not 404 and not woocommerce page */
		if (
			! is_404()
			&& ! wolf_is_woocommerce()
			&& ! is_singular( 'release' )
			&& ! is_singular( 'show' )
			&& ! is_singular( 'gallery' )
		) :

			if ( is_category() ) {

				$title = single_cat_title( '', false );
				$desc = category_description();

			} elseif ( is_tag() ) {

				$title = single_tag_title( '', false );
				$desc = category_description();

			} elseif ( is_author() ) {

				the_post();
				$title = get_the_author();
				rewind_posts();

			} elseif ( is_day() ) {

				get_the_date();

			} elseif ( is_month() ) {

				$title = get_the_date( 'F Y' );

			} elseif ( is_year() ) {

				$title = get_the_date( 'Y' );

			} elseif ( is_tax() ) {
				$the_tax = get_taxonomy( get_query_var( 'taxonomy' ) );
				if( $the_tax && $wp_query && isset($wp_query->queried_object->name) ) {

					$title = $wp_query->queried_object->name;
					$desc = category_description();
				}

			} elseif( is_search() ) {

				$title = sprintf( __( 'Search Results for: %s', 'wolf' ), get_search_query());

			} elseif ( is_single() ) {

				$format = get_post_format();

				if ( $format != 'quote'
				&& $format != 'aside'
				&& $format != 'status'
				&& $format != 'link'
				) {
					$title = get_the_title();
				}


			/* is blog index */
			} elseif (
				$wp_query && isset( $wp_query->queried_object->ID )
				&& $wp_query->queried_object->ID == get_option( 'page_for_posts' )
			 ) {

				$title = $wp_query->queried_object->post_title;
				$desc = wolf_get_theme_option( 'blog_tagline' ); // blog tagline from theme options

			} elseif ( $wp_query && isset( $wp_query->queried_object->ID )  ) {

				$title = $wp_query->queried_object->post_title;
			}

		endif; // if not 404
	endif; // end if have posts

	if ( $title )
		$output .= "<h1 class='page-title'>$title</h1>";

	if ( $title )
		$output .= "<div class='category-description'>$desc</div>";

	return $output;
}
endif;


// --------------------------------------------------------------------------


if ( ! function_exists( 'wolf_top_holder' ) ) :
/**
 * Output top holder area (mainly the page title container)
 */
function wolf_top_holder() {

	$content = wolf_get_holder_content( 'top_holder' );

	if ( $content ) :
	?>
	<section id="top-holder" class="clearfix">
		<div class="wrap"><?php echo $content; ?></div>
	</section>
	<?php
	endif;

}
add_action( 'wolf_header_after', 'wolf_top_holder' );
endif;


// --------------------------------------------------------------------------


if ( ! function_exists( 'wolf_intro' ) ) :
/**
 * Output top holder area (mainly the page title container)
 */
function wolf_intro() {

	//$format = get_post_format();

	if (
		! is_404()
		&& ! is_front_page()
		&& wolf_get_page_title()
	) :
	?>
	<section id="intro" class="clearfix">
		<div class="wrap">
			<?php echo wolf_get_page_title(); ?>
		</div>
	</section>
	<?php
	endif;
}
add_action( 'wolf_header_after', 'wolf_intro' );
endif;

// --------------------------------------------------------------------------


if ( ! function_exists( 'wolf_bottom_holder' ) ) :
/**
 * Output bottom holder area
 */
function wolf_bottom_holder() {

	$content = wolf_get_holder_content( 'bottom_holder' );

	if ( $content ) :
	?>
	<section id="bottom-holder" class="clearfix">
		<div class="wrap"><?php echo $content; ?></div>
	</section>
	<?php
	endif;
}
//add_action( 'wolf_header_after', 'wolf_bottom_holder' );
endif;

// --------------------------------------------------------------------------


if ( ! function_exists( 'wolf_get_holder_content' ) ) :
/**
 * Output bottom holder area
 */
function wolf_get_holder_content( $id = null ) {

	global $wp_query;
	$post_id = null;

	/* By default we pick the bottom message from theme custom options */
	$message = wolf_get_theme_option( $id );

	$meta_id = '_' . $id;

	if (
		have_posts()
		&& $wp_query
		&& isset( $wp_query->queried_object->ID )
		&& $wp_query->queried_object->ID != 0
	)
		$post_id = $wp_query->queried_object->ID;

	if ( ! is_404() && ! is_search() ) { // if no 404 or search

		$custom_types = array(

			'video' => array(
				'name' => 'video',
				'tax' => array( 'video_type'),
				'template_name' => 'videos'
			),

			'gallery' => array(
				'name' => 'gallery',
				'tax' => array( 'gallery_type' ),
				'template_name' => 'albums'
			),

			'release' => array(
				'name' => 'release',
				'tax' => array( 'label', 'band' ),
				'template_name' => 'discography'
			),

			'show' => array(
				'name' => 'show',
				'tax' => array(),
				'template_name' => ''
			)

		);

		foreach ( $custom_types as $key => $value ) {

			$index_page_id = wolf_get_custom_index_page_id( $value['template_name'] );

			foreach ( $value['tax'] as $tax ) {

				/* If we are on a taxonomy page, we display the message from the post type index page if set */
				if (
					$index_page_id
					&& get_post_meta( $index_page_id , $meta_id, true )
					&& is_tax( $tax )
				) {
					$message = get_post_meta( $index_page_id , $meta_id, true );
				}
			}

			/* If we are on a single post_type page, and index page message if set and the single custom post
			 *  does not have a message set, we display the index page message
			 */
			if (
				$post_id && $index_page_id  && get_post_meta( $index_page_id  , $meta_id, true )
				&& ! get_post_meta( $post_id, $meta_id, true )
				&& is_singular( $value['name'] )
			) {
				$message = get_post_meta( $index_page_id , $meta_id, true );
			}

		}

		/* WooCommerce
		---------------------------------------*/
		if (
			wolf_is_woocommerce()
			&& is_archive( 'product' )
		) {

			$message = get_post_meta( wolf_get_woocommerce_shop_page_id() , $meta_id, true );

		}


		/* Blog
		---------------------------------------*/
		/* If we are on an archive page, we display the blog message if set */
		if ( get_post_type() == 'post' && is_archive() && get_option('page_for_posts') && get_post_meta( get_option('page_for_posts') , $meta_id, true ) ){

			$message = get_post_meta( get_option('page_for_posts') , $meta_id, true );

		}

		/* If we're on a single blog post, a blog index message is set and no single post message found, we display the blog message */
		elseif (
			$post_id
			&& get_post_type() == 'post'
			&& get_option( 'page_for_posts' )
			&& is_single()
			&& ! get_post_meta( $post_id, $meta_id, true )  ) {

			$message = get_post_meta( get_option( 'page_for_posts' ) , $meta_id, true );
		}

		/* If a custom message post meta if set for a post */
		elseif ( $post_id && get_post_meta( $post_id, $meta_id, true ) ){
			$message = get_post_meta( $post_id, $meta_id, true );
		}
	}

	if ( $message && ! is_404() && ! is_search() ) {
		return wolf_format_custom_content_output( stripslashes( $message ) );
	}


}
endif;

// --------------------------------------------------------------------------

/**
 * Add title attribute to post navigation
 */
if ( ! function_exists( 'wolf_posts_link_next_title' ) ) :
add_filter( 'next_posts_link_attributes', 'wolf_posts_link_next_title' );
function wolf_posts_link_next_title() {
	return 'title="' . __( 'Older', 'wolf' ) . '"';
}
endif;

if ( ! function_exists( 'wolf_posts_link_prev_title' ) ) :
add_filter( 'previous_posts_link_attributes', 'wolf_posts_link_prev_title' );
function wolf_posts_link_prev_title() {
	return 'title="' . __( 'Newer', 'wolf' ) . '"';
}
endif;

// --------------------------------------------------------------------------


if ( ! function_exists( 'wolf_custom_gallery' ) ) :
/**
 * Custom Wordpress gallery shortcode output
 * Renders WP gallery differently depending on context (masonry gallery, slider, default)
 */
add_filter( 'use_default_gallery_style', '__return_false' );
add_filter( 'post_gallery', 'wolf_custom_gallery', 10, 2 );
function wolf_custom_gallery( $output, $attr) {
	global $post, $wp_locale;
	$post_id = get_the_ID();
	$is_masonry_gallery = get_post_type( $post_id ) == 'gallery';
	$is_slider = get_post_format( $post_id ) == 'gallery';
	$is_default = ! $is_slider && ! $is_masonry_gallery;

	$size = 'thumbnail';

	if ( $is_slider )
		$size = 'slide';

	if ( $is_masonry_gallery )
		$size = 'masonry-thumb';

	static $instance = 0;
	$instance++;

	// We're trusting author input, so let's at least make sure it looks like a valid orderby statement
	if ( isset( $attr['orderby'] ) ) {
		$attr['orderby'] = sanitize_sql_orderby( $attr['orderby'] );

		if ( ! $attr['orderby'] )
			unset( $attr['orderby'] );
	}

	extract(shortcode_atts(array(
		'order'      => 'ASC',
		'orderby'    => 'menu_order ID',
		'id'         => $post_id,
		'itemtag'    => 'li',
		'icontag'    => 'div',
		'captiontag' => 'dd',
		'columns'    => 3,
		'size'       => $size,
		'include'    => '',
		'exclude'    => ''
	), $attr));

	$id = intval($id);
	if ( 'RAND' == $order )
		$orderby = 'none';

	if ( !empty($include) ) {
		$include = preg_replace( '/[^0-9,]+/', '', $include );
		$_attachments = get_posts( array('include' => $include, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby) );

		$attachments = array();
		foreach ( $_attachments as $key => $val ) {
			$attachments[$val->ID] = $_attachments[$key];
		}

	} elseif ( !empty($exclude) ) {
		$exclude = preg_replace( '/[^0-9,]+/', '', $exclude );
		$attachments = get_children( array('post_parent' => $id, 'exclude' => $exclude, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby) );
	} else {
		$attachments = get_children( array('post_parent' => $id, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby) );
	}

	if ( empty($attachments) )
		return '';

	if ( is_feed() ) {
		$output = "\n";
		foreach ( $attachments as $att_id => $attachment )
		$output .= wp_get_attachment_link($att_id, $size, true) . "\n";
		return $output;
	}

	$itemtag = tag_escape($itemtag);
	$captiontag = tag_escape($captiontag);
	$columns = intval($columns);
	$itemwidth = $columns > 0 ? floor(100/$columns) : 100;
	$float = is_rtl() ? 'right' : 'left';

	$rand = rand(1,999);
	$gallery_id = $post_id.$rand;
	$selector = "gallery-$gallery_id";

	$class = "clearfix gallery default-gallery";

	if ( $is_masonry_gallery )
		$class = "clearfix gallery masonry-gallery";

	$open_tag = "<div id='$selector' class='$class'><ul>";

	if ( $is_slider )
		$open_tag = "<div id='$selector' class='clearfix flexslider wolf-gallery-slider'><ul class='slides'>";

	$gallery_style = '';

	if ( $is_default  ){
		$gallery_style = "<style type='text/css'>
	            #{$selector}.default-gallery {
	                margin: auto;
	                margin-bottom:1em;
	            }
	            #{$selector}.default-gallery ul li {
	                float: {$float};
	                margin-top: 10px;
	                text-align: center;
	                width: {$itemwidth}%;           }
	            #{$selector}.default-gallery img {
	                border: 2px solid #cfcfcf;
	            }
	            #{$selector}.default-gallery .gallery-caption {
	                margin-left: 0;
	            }
	        </style>";
	}

	$output = apply_filters('gallery_style', "$gallery_style
	<!-- see gallery_shortcode() in wp-includes/media.php -->
	$open_tag");

	//debug( $size );

	$i = 0;
	foreach ( $attachments as $id => $attachment ) {

		$caption = '';
		$link_class = '';
		$data_thumb_attr = '';
		$fallback = '';
		$img = wp_get_attachment_image_src( $id, $size, false, false );
		$full = wp_get_attachment_image_src( $id, 'full', false, false );
		$square = wp_get_attachment_image_src( $id, 'small-square', false, false );

		if ( $captiontag && trim($attachment->post_excerpt) )
			$caption = wptexturize($attachment->post_excerpt);

		if ( $img[0] && $full[0] && $square[0] ){

			$src = $img[0];
			$full_size = $full[0];
			$square_fallback = $square[0];

			//if ( $data_thumb[0] && $is_slider ){
			//	$data_thumb_attr = ' data-thumb="'. $data_thumb[0] .'"';
			//}

			if ( ! $is_slider ){

				$link_class = ' class="lightbox"';

			}else{
				$link_class = ' class="post-opener"';
				$fallback =  " data-src='$src' data-src-mobile='$square_fallback'";
			}


			$img = '<a'. $link_class .' title="'. $caption .'" href="'. $full_size .'" rel="lightbox[gallery-' . $post->ID . ']">
<img' . $fallback . ' src="' . $src . '" alt="'. wptexturize( $attachment->post_title ) .'"></a>';
		}

		$link = isset($attr['link']) && 'post' == $attr['link'] ? wp_get_attachment_link($id, $size, true, false) : $img;

		if ( $is_slider ){
			$output .= "<{$itemtag} class='slide'";

			//$output .= $data_thumb_attr;

			$output .= ">";

		}else{
			$output .= "<{$itemtag}>";
		}

		$output .= "$link";

		if ( $caption && $is_slider )
			$output .= "<p class='flex-caption'>$caption</p>";

		$output .= "</{$itemtag}>";
	}


	$output .= "</ul></div>\n";


	return $output;
}
endif;